/*
 * Simulator of microcontrollers (cmd.src/cmdsetcl.h)
 *
 * Copyright (C) 1999,99 Drotos Daniel, Talker Bt.
 * 
 * To contact author send email to drdani@mazsola.iit.uni-miskolc.hu
 *
 */

/* This file is part of microcontroller simulator: ucsim.

UCSIM is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

UCSIM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with UCSIM; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA. */
/*@1@*/

#ifndef CMD_CMDSETCL_HEADER
#define CMD_CMDSETCL_HEADER

#include "newcmdcl.h"


#define START_CMD_CL(NAME) class cl_NAME_cmd: public cl_cmd\
{\
public:\
  cl_NAME_cmd(class cl_sim *asim,\
	      char *aname,\
	      int  can_rep,\
	      char *short_help,\
	      char *long_help):\
    cl_sim(asim, aname, can_rep, short_help, long_help) {}\
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
#define END_CMD_CL };
#define CMD_CL(NAME) START_CMD_CL(NAME) END_CMD_CL

// CONF
class cl_conf_cmd: public cl_cmd
{
public:
  cl_conf_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// STATE
class cl_state_cmd: public cl_cmd
{
public:
  cl_state_cmd(class cl_sim *asim,
	       char *aname,
	       int  can_rep,
	       char *short_hlp,
	       char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// FILE
class cl_file_cmd: public cl_cmd
{
public:
  cl_file_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DOWNLOAD
class cl_dl_cmd: public cl_cmd
{
public:
  cl_dl_cmd(class cl_sim *asim,
	    char *aname,
	    int  can_rep,
	    char *short_hlp,
	    char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// TIMER
class cl_timer_cmd: public cl_cmd
{
public:
  class cl_ticker *ticker;
  long what;
  char *name;

  cl_timer_cmd(class cl_sim *asim,
	       char *aname,
	       int  can_rep,
	       char *short_hlp,
	       char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
  void set_ticker(class cl_cmd_arg *param);
  virtual int add(class cl_cmdline *cmdline, class cl_console *con);
  virtual int del(class cl_cmdline *cmdline, class cl_console *con);
  virtual int get(class cl_cmdline *cmdline, class cl_console *con);
  virtual int run(class cl_cmdline *cmdline, class cl_console *con);
  virtual int stop(class cl_cmdline *cmdline, class cl_console *con);
  virtual int val(class cl_cmdline *cmdline, class cl_console *con);
};

// RUN
class cl_run_cmd: public cl_cmd
{
public:
  cl_run_cmd(class cl_sim *asim,
	     char *aname,
	     int  can_rep,
	     char *short_hlp,
	     char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// STOP
class cl_stop_cmd: public cl_cmd
{
public:
  cl_stop_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// STEP
class cl_step_cmd: public cl_cmd
{
public:
  cl_step_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// NEXT
class cl_next_cmd: public cl_cmd
{
public:
  cl_next_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// PC
class cl_pc_cmd: public cl_cmd
{
public:
  cl_pc_cmd(class cl_sim *asim,
	    char *aname,
	    int  can_rep,
	    char *short_hlp,
	    char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// RESET
class cl_reset_cmd: public cl_cmd
{
public:
  cl_reset_cmd(class cl_sim *asim,
	       char *aname,
	       int  can_rep,
	       char *short_hlp,
	       char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DUMP
class cl_dump_cmd: public cl_cmd
{
public:
  cl_dump_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  //cl_dump_cmd(class cl_sim *asim): cl_cmd(asim) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DI
class cl_di_cmd: public cl_dump_cmd
{
public:
  cl_di_cmd(class cl_sim *asim,
	    char *aname,
	    int  can_rep,
	    char *short_hlp,
	    char *long_hlp):
    cl_dump_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DX
class cl_dx_cmd: public cl_dump_cmd
{
public:
  cl_dx_cmd(class cl_sim *asim,
	    char *aname,
	    int  can_rep,
	    char *short_hlp,
	    char *long_hlp):
    cl_dump_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DCH
class cl_dch_cmd: public cl_dump_cmd
{
public:
  cl_dch_cmd(class cl_sim *asim,
	     char *aname,
	     int  can_rep,
	     char *short_hlp,
	     char *long_hlp):
    cl_dump_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DS
class cl_ds_cmd: public cl_dump_cmd
{
public:
  cl_ds_cmd(class cl_sim *asim,
	    char *aname,
	    int  can_rep,
	    char *short_hlp,
	    char *long_hlp):
    cl_dump_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DC
class cl_dc_cmd: public cl_cmd
{
public:
  t_addr last;
public:
  cl_dc_cmd(class cl_sim *asim,
	    char *aname,
	    int  can_rep,
	    char *short_hlp,
	    char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {last=0;}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// DISASSEMBLE
class cl_disassemble_cmd: public cl_cmd
{
public:
  int last;
public:
  cl_disassemble_cmd(class cl_sim *asim,
		     char *aname,
		     int  can_rep,
		     char *short_hlp,
		     char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {last=0;}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// FILL
class cl_fill_cmd: public cl_cmd
{
public:
  int last;
public:
  cl_fill_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {last=0;}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// WHERE
class cl_where_cmd: public cl_cmd
{
public:
  int last;
public:
  cl_where_cmd(class cl_sim *asim,
	       char *aname,
	       int  can_rep,
	       char *short_hlp,
	       char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {last=0;}
  virtual int do_real_work(class cl_cmdline *cmdline, class cl_console *con,
			   bool case_sensitive);
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// WHERE
class cl_Where_cmd: public cl_where_cmd
{
public:
  int last;
public:
  cl_Where_cmd(class cl_sim *asim,
	       char *aname,
	       int  can_rep,
	       char *short_hlp,
	       char *long_hlp):
    cl_where_cmd(asim, aname, can_rep, short_hlp, long_hlp) {last=0;}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// HELP
class cl_help_cmd: public cl_cmd
{
public:
  cl_help_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// QUIT
class cl_quit_cmd: public cl_cmd
{
public:
  cl_quit_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};

// KILL
class cl_kill_cmd: public cl_cmd
{
public:
  cl_kill_cmd(class cl_sim *asim,
	      char *aname,
	      int  can_rep,
	      char *short_hlp,
	      char *long_hlp):
    cl_cmd(asim, aname, can_rep, short_hlp, long_hlp) {}
  virtual int do_work(class cl_cmdline *cmdline, class cl_console *con);
};


#endif

/* End of cmd.src/cmdsetcl.h */
